@@ -129,6 +129,11 @@ class VariableClAutopartitionSwapSize(SizeHelper, AutopartitionHelper,
             size = Sizes.G
         return str(size)
 
+    def check(self, value):
+        if value.isdigit() and int(value) <= Sizes.M:
+            raise VariableError(
+                _("Swap size should not be less that 1MiB"))
+
     def humanReadable(self):
         return humanreadableSize(int(self.Get()))
 
